@@ -112,28 +112,29 @@ class Weather():
             print(" City Not Found ")
 
 
-if __name__ == "__main__": 
-    # get name of the city from user
 
-#     city_name = input("Enter city name : ")
-    # declaring queue to get return values from user defined functions
-    my_queue = queue.Queue()
-    w1 = Weather()
-    #Thread t1 executing the get_api_url() function
-    t1 = threading.Thread(target=w1.get_api_url(city_name,my_queue))
-    #start thread t1
-    t1.start()
-    # main program to wait till Thread t1 is completed
-    t1.join()
-    # get the return value from the get_api_url function
-    func_value = my_queue.get()
-    # Thread t2 executing get_city_weather_info() function
-    t2 = threading.Thread(target=w1.get_city_weather_info(func_value,my_queue))
-    #start thread t2
-    t2.start()
-    # main program to wait till Thread t2 is completed
-    t2.join()
-    # get the return value from the get_city_weather_info function
-    func_value = my_queue.get()
-    # executing the get_fifth_day_weather function that write data to file
-    w1.get_fifth_day_weather(func_value)
\ No newline at end of file
+# get name of the city from user
+
+#city_name = input("Enter city name : ")
+city_name = sys.argv[0]
+# declaring queue to get return values from user defined functions
+my_queue = queue.Queue()
+w1 = Weather()
+#Thread t1 executing the get_api_url() function
+t1 = threading.Thread(target=w1.get_api_url(city_name,my_queue))
+#start thread t1
+t1.start()
+# main program to wait till Thread t1 is completed
+t1.join()
+# get the return value from the get_api_url function
+func_value = my_queue.get()
+# Thread t2 executing get_city_weather_info() function
+t2 = threading.Thread(target=w1.get_city_weather_info(func_value,my_queue))
+#start thread t2
+t2.start()
+# main program to wait till Thread t2 is completed
+t2.join()
+# get the return value from the get_city_weather_info function
+func_value = my_queue.get()
+# executing the get_fifth_day_weather function that write data to file
+w1.get_fifth_day_weather(func_value)
\ No newline at end of file
